About - llvm-py
Description: Python bindings for LLVM
Keywords: llvm python compiler backend bindings

llvm-py
Python Bindings for LLVM

»Home »Examples »Download »User Guide »Contribute »License »About | # About llvm-py is developed and maintained by Mahadevan R, with contributions from many users all over the world. He can be reached at mdevan@mdevan.org, on the llvm-dev mailing list and (sometimes) as mdevan on irc.oftc.net#llvm. Many thanks to the guys over at LLVM for all the nifty software, for all the llvm-py contributors.